Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/esp_atcontrol_simpletest.py
    :caption: examples/esp_atcontrol_simpletest.py
    :linenos:
